@@ -23,6 +23,8 @@ def needed_TAs(event):
 
   if "laboration" in event.name or "Laboration" in event.name:
     num_TAs = round(num_TAs * 1.5)
+  elif "Övning" in event.name and event.weekday() in [3, 4]:
+    num_TAs = 1
 
   return num_TAs
   
@@ -112,7 +114,7 @@ def hours_per_TA(csv_rows):
   Input: Rows of CSV data as from csv.reader.
 
   Output: a dictionary mapping a TA to the number of hours they signed up for 
-  in the sign-up sheet, {TA: hours}
+  in the sign-up sheet, {TA: hours}. The hours as datetime.timedelta objects.
   """
   TA_hours = {}
 
@@ -138,21 +140,23 @@ def total_hours(csv_rows):
   """
   Input: Rows of CSV data as from csv.reader.
 
-  Output: Total number of hours spent on the course.
+  Output: Total number of hours spent on the course, as a datetime.timedelta 
+  object.
   """
   total = 0.0
   TA_hours = hours_per_TA(csv_rows)
   TA_hours[""] = 0
 
   for _, hours in TA_hours.items():
-    total += float(hours)
+    total += hours
 
   return total
 def max_hours(csv_rows):
   """
   Input: takes the rows of CSV as output from csv.reader.
 
-  Output: returns the maximum number of hours (using maximum TAs needed).
+  Output: returns the maximum number of hours (using maximum TAs needed), as a 
+  detetime.timedelta object.
   """
   start_index = SIGNUP_SHEET_HEADER.index("Start")
   end_index = SIGNUP_SHEET_HEADER.index("End")
